<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JA">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>情報: </translation>
    </message>
    <message>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>寄付</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>ライセンス: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">消去</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation type="unfinished">秒</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation type="unfinished">追加</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>ウォーターマーク画像が必要です</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>「オプション」 &gt; 「設定」 &gt; 「注釈」 &gt; 「更新」でウォーターマーク画像を追加してください</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>パスの描画を滑らかにする</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>有効にすると、ペンツールやマーカーツールで
線を引き終わった時に、線を滑らかにします。</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>滑らか係数</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>滑らか係数を大きくするとペンツールやマーカー
ツールの精度が落ち、より一層滑らかになります。</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>注釈設定</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>注釈ツールの選択を記憶して起動時に読み込みます</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>アイテムを描画したら選択ツールに切り替える</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>起動時に既定のモードでスクリーンショットを撮る</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>アプリケーションスタイル</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>GUI のルックアンドフィールを定義するアプリケーションスタイルを設定します。
この変更は ksnip を再起動すると有効になります。</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>アプリケーション設定</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>自動的に新しいキャプチャーをクリップボードにコピーする</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>タブを使用する</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>変更には再起動が必要です。</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>ksnip をシングルインスタンスとして実行する</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>タブが一つの時はタブバーを隠します。</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>このオプションを有効にすると、実行できる ksnip のインスタンス
は一つだけになり、他のインスタンスを起動すると起動済みのイン
スタンスに引数を渡して終了するようになります。このオプション
の変更には、すべてのインスタンスを終了する必要があります。</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>メインウィンドウの位置を記憶して起動時に読み込む</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>貢献者:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>スペイン語訳</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>オランダ語訳</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>ロシア語訳</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>ノルウェー語 (ブークモール) 訳</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>フランス語訳</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>ポーランド語訳</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap と Flatpak のサポート</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>警告 - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>キャプチャー %1%2%3 は変更されています。
保存しますか？</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>マウスで四角く選択します</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>最近選択した範囲のスクリーンショットをキャプチャーします</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>すべてのモニターの全画面をキャプチャーします</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>マウスカーソルがある画面をキャプチャーします</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>現在フォーカスがあるウィンドウをキャプチャーします</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>現在マウスカーソルがあるウィンドウをキャプチャーします</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>スクリーンショットの取得に Screenshot Portal を使用します</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>画像を削除</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>&apos;%1&apos; を削除します。
続行しますか？</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>寄付はいつでも大歓迎です</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>寄付</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation type="unfinished">選択範囲</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation type="unfinished">最近の選択範囲</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation type="unfinished">全画面 (すべてのモニター)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation type="unfinished">現在の画面</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation type="unfinished">アクティブウィンドウ</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation type="unfinished">カーソルがあるウィンドウ</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation type="unfinished">Screenshot Portal</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">ユーザー名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>アップロードに成功しました</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>アップロードするための一時画像を保存できません。</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>プロセスを起動できません。パスとパーミッションを確認してください。</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>プロセスがクラッシュしました</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>プロセスがタイムアウトしました。</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>プロセスの読み取りエラーです。</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>プロセスの書き込みエラーです。</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>ウェブのエラーです。コンソールの出力を確認してください。</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>アップロードに失敗しました</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>スクリプトが StdErr に書き込みました。</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>グローバルホットキーを有効にする</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>選択範囲をキャプチャー</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>最近選択した範囲をキャプチャー</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>全画面をキャプチャー</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>現在の画面をキャプチャー</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>アクティブウィンドウをキャプチャー</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>カーソルがあるウィンドウをキャプチャー</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>グローバルホットキー</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Portal を使用してキャプチャー</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>マウスカーソルもキャプチャーする</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>スクリーンショットにマウスカーソルを
表示させたい場合は有効にしてください。</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>画像取得</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>スクリーンショット撮影後にメインウィンドウを表示する</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>スクリーンショット撮影中はメインウィンドウを隠す</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>新しいスクリーンショットを撮る時にメインウィンドウを非表示にします。</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur の履歴</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>タイムスタンプ</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>リンク</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>削除リンク</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>imgur.com へのアップロードが完了しました！</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>新しいトークンを受け取りました。アップロードを再試行しています…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur トークンの期限切れです。新しいトークンを要求しています…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>匿名アップロードを強制する</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>アップロード後 Imgur のリンクを既定のブラウザーで開く</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>常に Imgur のリンクをクリップボードにコピーする</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Client ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Client Secret</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>トークン変換用の Imgur PIN を入力してください。</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>PIN を取得</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>トークンを取得</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur の履歴</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur アップローダー</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>imgur.com を待っています…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com トークンの更新に成功しました。</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com トークンの更新エラーです。</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>画像に直接リンクする</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>ベース URL:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Imgur との通信時に使用するベース URL です。
変更には再起動が必要です。</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>スクリーンショット撮影までの
遅延秒数です。</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>秒</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>スクリーンキャプチャーをファイルシステムに保存します</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>スクリーンキャプチャーをクリップボードにコピーします</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>やり直す</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>切り抜く</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>スクリーンキャプチャーを切り抜きます</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unable to show image</source>
        <translation>画像を表示できません</translation>
    </message>
    <message>
        <source>Unsaved</source>
        <translation>未保存</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>アップロード</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>印刷</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>印刷ダイアログを開き画像印刷オプションを提供します</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>印刷プレビュー</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>画像の向きを変更できる印刷プレビューダイアログを開きます</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>拡大縮小</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>ウォーターマークを追加</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>キャプチャーした画像にウォーターマークを追加します。ウォーターマークは複数追加できます。</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>情報(&amp;A)</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>オプション(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>名前を付けて保存...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>貼り付け (埋め込み)</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>ピン留め</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>スクリーンショットを枠のないウィンドウ内に前景としてピン留めします</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>パスをコピー</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>ディレクトリを開く</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>名前を変更</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>画像を開く</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>ディレクトリを開く</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>パスをコピー</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>名前を変更</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>キャプチャー</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>他のを閉じる</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>すべて閉じる</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>ピン留めウィンドウ %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>画像の名前を変更しました</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>画像の名前を変更できませんでした</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>画像の名前を変更</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>新しいファイル名:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>すべてのファイル</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>画像を保存しました</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>画像の保存に失敗しました</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>自動的に新しいキャプチャーを既定の場所に保存する</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>未保存の変更を破棄する前に保存するか確認する</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>最後に保存したディレクトリを記憶する</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>有効にすると、保存するたびに
保存先の設定が上書きされます。</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>キャプチャーの保存場所とファイル名</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>JPG、PNG、BMP をサポートしています。ファイル形式を指定しない場合は PNG になります。
ファイル名には次のワイルドカードを含めることができます:
- 日付: $Y, $M, $D, 時刻: $h, $m, $s, hhmmss 形式の時刻: $T
- 番号を表す連続した #。#### は 0001 に置換され、0002 のように増加します。</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>参照</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>保存設定</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>キャプチャーの保存場所</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>既定</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>係数</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>保存品質</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>ファイルを圧縮して小さくしたい場合は 0 を、大きくても非圧縮にしたい場合は 100 を指定してください。
JPEG 以外の画像形式は 0 から 100 までの範囲をサポートしていない場合があります。</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>スクリプトの出力をクリップボードにコピーする</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>スクリプト:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>アップロード用のスクリプトのパス。スクリプトは、アップロード中に
単一の一時ファイル (PNG) を引数として呼び出されます。</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>参照</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>スクリプトアップローダー</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>アップロードスクリプトを選択</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>アップロードスクリプトが StdErr に書き込む時に停止する</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>スクリプトが StdErr に書き込む時に、アップロードに失敗したとしてマークします。
この設定がないとスクリプト内のエラーに気付けません。</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>絞り込み:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>正規表現の式です。この正規表現に一致するもののみクリップボードにコピーします。
省略した場合、すべてコピーします。</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>アプリケーション</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>画像取得</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur アップローダー</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>注釈</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>ホットキー</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>アップローダー</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>スクリプトアップローダー</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>ステッカー</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation type="unfinished">範囲選択画面で画像を固定する</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished">範囲選択画面で拡大鏡を表示する</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished">背景画像を拡大する拡大鏡を表示します。
このオプションは「範囲選択画面で画像を
固定する」が有効な場合のみ動作します。</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished">範囲選択画面でルーラーを表示する</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished">マウスカーソルから画面端まで
横線と縦線を表示します。</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished">範囲選択画面でカーソル位置情報や選択サイズ情報を表示する</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished">マウスの左ボタンを押していない場合は
カーソルの位置情報が表示され、押して
いる場合は選択範囲の長さが表示されま
す。</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished">有効にすると、範囲選択後にそのサイズを変更
できるようになります。
サイズ変更後に Return キーを押すと確定します。</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished">範囲選択カーソルの色</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished">範囲選択カーソルの色を設定します。</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished">範囲選択カーソルの太さ</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished">範囲選択カーソルの太さを設定します。</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>上へ</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>下へ</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>既定のステッカーを使用する</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>ステッカー設定</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>ベクター画像ファイル (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>ステッカーを追加</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>エディターを表示</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation type="unfinished">トレイアイコンを使用する</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished">有効にすると、タスクバーにトレイアイコンを追加します 
(OS のウィンドウマネージャーがサポートしている場合)。
変更には再起動が必要です。</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation type="unfinished">最小化したらトレイに格納する</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation type="unfinished">トレイに最小化して起動する</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation type="unfinished">ウィンドウを閉じたらトレイに格納する</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished">エディターを表示</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation type="unfinished">キャプチャー</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>画像を選択</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>アップロードスクリプトが必要です</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>「オプション」 &gt; 「設定」 &gt; 「アップロードスクリプト」でアップロードスクリプトを追加してください</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>キャプチャーをアップロード</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>外部の場所に画像をアップロードしようとしています。続行しますか？</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>アップロード前に確認する</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>アップローダーの種類:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>スクリプト</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>アップローダー</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>ビルド</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>使用:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation type="unfinished">ウォーターマーク画像</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">更新</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation type="unfinished">ウォーターマークを傾ける</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished">有効にするとウォーターマークが 45° 傾いた状態になります</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
